import os
import psycopg2

DB_ADDRESS = os.environ['DB_ADDRESS']
DB_USER = os.environ['DB_USER']
DB_PASSWORD = os.environ['DB_PASSWORD']
DB_NAME = os.environ['DB_NAME']


class DBConnector:
    """Context managed database class. Use with statements to automatically open and close the database connection, like
    so:

    .. code-block:: python
       with DBConnector() as db:
           db.read()
    """
    def __enter__(self):
        self.conn = psycopg2.connect()
        self.cur = self.conn.cursor()

    def __exit__(self):
        self.cur.close()
        self.conn.close()

    def _query(self, sql):
        self.cur.execute(sql)